{% extends "template/template.html" %}
{% block title%}Reports{% endblock %}
{% block content %}
<h1>Reports</h1>
    {% for module,reports in reports %}
        <DIV CLASS="module">
            <TABLE SUMMARY="Reports available for {{module}} application" WIDTH="100%">
            <CAPTION><A HREF="" CLASS="section">{{module}}</A></CAPTION>
            {% for r in reports %}
                <TR><TH SCOPE="row"><A HREF="/main/report/{{r.name}}/">{{r.title}}</A></TH></TR>
            {% endfor %}
            </TABLE>
        </DIV>
    {% endfor %}
{% endblock %}
