# -*- coding: utf-8 -*-
##----------------------------------------------------------------------
## Copyright (C) 2007-2009 The NOC Project
## See LICENSE for details
##----------------------------------------------------------------------
"""
"""
from noc.sa.interfaces.base import *
from noc.sa.interfaces.igetconfig import IGetConfig
from noc.sa.interfaces.igetvlans import IGetVlans
from noc.sa.interfaces.ihasvlan import IHasVlan
from noc.sa.interfaces.igetversion import IGetVersion
from noc.sa.interfaces.igetmacaddresstable import IGetMACAddressTable
from noc.sa.interfaces.igetdot11associations import IGetDot11Associations
from noc.sa.interfaces.iping import IPing

