.rackset {
    border: 2px solid black;
    font-size: 10pt;
    caption-side: bottom;
}

.rackset .ruler {
    text-align: right;
    vertical-align: middle;
    width: 1em;
    border: 1px solid;
    padding: 1px;
    margin: 0px;
    height: 14pt;
    color: #ffffff;
    background-color: #999999;
}

.rackset .occupied {
    text-align: center;
    border: 1px solid black;
    vertical-align: middle;
    width: 20em;
}

.rackset .empty {
    background-color: #999999;
    border: 1px solid black;
    width: 20em;
}

.rackset .emptytop {
    border-bottom: 2px solid black;
}

.rackset .racklabel {
    text-align: center;
    border-right: 1px solid #999999;
}