@import url("/media/css/dashboard.css");

#footer {
	text-align: center;
}

#content {
    margin-left: 204px;
    min-height: 400px;
}

div.breadcrumbs {
    margin-left: 204px;
}

ul.messagelist {
    margin-left: 204px;
}

#changelist table thead th {
    white-space: normal;
}

#user-tools FORM {
    display: inline;
}

#user-tools INPUT {
    margin-top: -2px;
    width: 140px;
}

@media print {
    #menu {
        display: none;
    }
    
    #content {
        margin-left: 0px;
    }
    
    div.breadcrumbs {
        margin-left: 0px;
    }
    
    ul.messagelist {
        margin-left: 0px;
    }
}